pub struct H3Client<C, B>where
C: H3Connector,
B: Body + Send + 'static + Unpin,
B::Data: Send,
B::Error: Into<Error> + Send,{ /* private fields */ }Expand description
http3 client. Note the client does not do dns resolve but blindly sends requests using connections created by the connector.
Implementations